# Model Explorer

Model Explorer offers an intuitive and hierarchical visualization of model
graphs. It organizes model operations into nested layers, enabling users to
dynamically expand or collapse these layers. It also provides a range of
features to facilitate model exploration and debugging, including the ability to
highlight input and output operations, overlay metadata on nodes, display layers
in interactive pop-ups, perform searches, show identical layers, GPU-accelerated
graph rendering, among others. It currently supports TFLite, TF, TFJS, MLIR, and
PyTorch (Exported Program) model format, and provides an extension framework for
developers to easily add support for additional formats.

![](https://raw.githubusercontent.com/google-ai-edge/model-explorer/main/screenshots/main_ui.png)

<br>
<br>

Please check out our [Wiki](https://github.com/google-ai-edge/model-explorer/wiki) for
more details:

- [Installation](https://github.com/google-ai-edge/model-explorer/wiki/1.-Installation)
- [User Guide](https://github.com/google-ai-edge/model-explorer/wiki/2.-User-Guide)
- [Command Line Guide](https://github.com/google-ai-edge/model-explorer/wiki/3.-Command-Line-Guide)
- [API Guide](https://github.com/google-ai-edge/model-explorer/wiki/4.-API-Guide)
- [Run in Colab Notebook](https://github.com/google-ai-edge/model-explorer/wiki/5.-Run-in-Colab-Notebook)
- [Develop Adapter Extension](https://github.com/google-ai-edge/model-explorer/wiki/6.-Develop-Adapter-Extension)
